==> striprtf_0.2.2.tar.gz: striprtf/R/global.R <==

.destinations <- c(
  "aftncn", "aftnsep", "aftnsepc", "annotation",
  "atnauthor", "atndate", "atnicn", "atnid",
  "atnparent", "atnref", "atntime", "atrfend",
  "atrfstart", "author", "background",
  "bkmkend", "bkmkstart", "blipuid", "buptim",
  "category", "colorschememapping",
  "colortbl", "comment", "company", "creatim",
  "datafield", "datastore", "defchp", "defpap",
  "do", "doccomm", "docvar", "dptxbxtext", "ebcend",
  "ebcstart", "factoidname", "falt",
  "fchars", "ffdeftext", "ffentrymcr", "ffexitmcr",
  "ffformat", "ffhelptext", "ffl",
  "ffname", "ffstattext", "field", "file", "filetbl",
  "fldinst", "fldrslt", "fldtype",
  "fname", "fontemb", "fontfile", "fonttbl",
  "footer", "footerf", "footerl", "footerr",
  "footnote", "formfield", "ftncn", "ftnsep",
  "ftnsepc", "g", "generator", "gridtbl",
  "header", "headerf", "headerl", "headerr", "hl",
  "hlfr", "hlinkbase", "hlloc", "hlsrc",
  "hsv", "htmltag", "info", "keycode", "keywords",
  "latentstyles", "lchars", "levelnumbers",
  "leveltext", "lfolevel", "linkval", "list", "listlevel",
  "listname", "listoverride",
  "listoverridetable", "listpicture", "liststylename",
  "listtable", "listtext",
  "lsdlockedexcept", "macc", "maccPr", "mailmerge", "maln",
  "malnScr", "manager", "margPr",
  "mbar", "mbarPr", "mbaseJc", "mbegChr", "mborderBox",
  "mborderBoxPr", "mbox", "mboxPr",
  "mchr", "mcount", "mctrlPr", "md", "mdeg", "mdegHide",
  "mden", "mdiff", "mdPr", "me",
  "mendChr", "meqArr", "meqArrPr", "mf", "mfName", "mfPr",
  "mfunc", "mfuncPr", "mgroupChr",
  "mgroupChrPr", "mgrow", "mhideBot", "mhideLeft", "mhideRight",
  "mhideTop", "mhtmltag",
  "mlim", "mlimloc", "mlimlow", "mlimlowPr", "mlimupp",
  "mlimuppPr", "mm", "mmaddfieldname",
  "mmath", "mmathPict", "mmathPr", "mmaxdist", "mmc", "mmcJc",
  "mmconnectstr", "mmconnectstrdata", "mmcPr", "mmcs",
  "mmdatasource", "mmheadersource", "mmmailsubject",
  "mmodso", "mmodsofilter", "mmodsofldmpdata", "mmodsomappedname",
  "mmodsoname", "mmodsorecipdata", "mmodsosort",
  "mmodsosrc", "mmodsotable", "mmodsoudl",
  "mmodsoudldata", "mmodsouniquetag", "mmPr",
  "mmquery", "mmr", "mnary", "mnaryPr",
  "mnoBreak", "mnum", "mobjDist", "moMath", "moMathPara",
  "moMathParaPr", "mopEmu",
  "mphant", "mphantPr", "mplcHide", "mpos", "mr", "mrad",
  "mradPr", "mrPr", "msepChr",
  "mshow", "mshp", "msPre", "msPrePr", "msSub", "msSubPr",
  "msSubSup", "msSubSupPr", "msSup",
  "msSupPr", "mstrikeBLTR", "mstrikeH", "mstrikeTLBR", "mstrikeV",
  "msub", "msubHide", "msup", "msupHide", "mtransp", "mtype",
  "mvertJc", "mvfmf", "mvfml", "mvtof", "mvtol",
  "mzeroAsc", "mzeroDesc", "mzeroWid", "nesttableprops",
  "nextfile", "nonesttables",
  "objalias", "objclass", "objdata", "object", "objname",
  "objsect", "objtime", "oldcprops",
  "oldpprops", "oldsprops", "oldtprops", "oleclsid", "operator",
  "panose", "password",
  "passwordhash", "pgp", "pgptbl", "picprop", "pict", "pn", "pnseclvl",
  "pntext", "pntxta",
  "pntxtb", "printim", "private", "propname", "protend", "protstart",
  "protusertbl", "pxe",
  "result", "revtbl", "revtim", "rsidtbl", "rxe", "shp", "shpgrp", "shpinst",
  "shppict", "shprslt", "shptxt", "sn",
  "sp", "staticval", "stylesheet", "subject", "sv",
  "svb", "tc", "template", "themedata", "title", "txe", "ud",
  "upr", "userprops",
  "wgrffmtfilter", "windowcaption", "writereservation", "writereservhash",
  "xe", "xform", "xmlattrname", "xmlattrvalue",
  "xmlclose", "xmlname", "xmlnstbl", "xmlopen"
)



.specialchars <- list(
  keys = c("bullet", "emdash", "emspace", "endash", "enspace",
           "ldblquote", "line", "lquote", "page", "par",
           "qmspace", "rdblquote", "rquote", "sect", "tab"),
  hexstr = c("x2022", "x2014", "x2003", "x2013", "x2002",
             "x201C", "x000A", "xu2018", "x000Ax000A", "x000A",
             "x2005", "x201D", "x2019", "x000Ax000A", "x0009"),
  str = c("\u2022", "\u2014", "\u2003", "\u2013", "\u2002",
          "\201C", "\n", "\u2018", "\n\n", "\n",
          "\u2005", "\u201D", "\u2019",  "\n\n", "\t")
)

==> striprtf_0.4.3.tar.gz: striprtf/R/global.R <==

.destinations <- c(
  "aftncn", "aftnsep", "aftnsepc", "annotation",
  "atnauthor", "atndate", "atnicn", "atnid",
  "atnparent", "atnref", "atntime", "atrfend",
  "atrfstart", "author", "background",
  "bkmkend", "bkmkstart", "blipuid", "buptim",
  "category", "colorschememapping",
  "colortbl", "comment", "company", "creatim",
  "datafield", "datastore", "defchp", "defpap",
  "do", "doccomm", "docvar", "dptxbxtext", "ebcend",
  "ebcstart", "factoidname", "falt",
  "fchars", "ffdeftext", "ffentrymcr", "ffexitmcr",
  "ffformat", "ffhelptext", "ffl",
  "ffname", "ffstattext", "field", "file", "filetbl",
  "fldinst", "fldrslt", "fldtype",
  "fname", "fontemb", "fontfile", "fonttbl",
  "footer", "footerf", "footerl", "footerr",
  "footnote", "formfield", "ftncn", "ftnsep",
  "ftnsepc", "g", "generator", "gridtbl",
  "header", "headerf", "headerl", "headerr", "hl",
  "hlfr", "hlinkbase", "hlloc", "hlsrc",
  "hsv", "htmltag", "info", "keycode", "keywords",
  "latentstyles", "lchars", "levelnumbers",
  "leveltext", "lfolevel", "linkval", "list", "listlevel",
  "listname", "listoverride",
  "listoverridetable", "listpicture", "liststylename",
  "listtable", "listtext",
  "lsdlockedexcept", "macc", "maccPr", "mailmerge", "maln",
  "malnScr", "manager", "margPr",
  "mbar", "mbarPr", "mbaseJc", "mbegChr", "mborderBox",
  "mborderBoxPr", "mbox", "mboxPr",
  "mchr", "mcount", "mctrlPr", "md", "mdeg", "mdegHide",
  "mden", "mdiff", "mdPr", "me",
  "mendChr", "meqArr", "meqArrPr", "mf", "mfName", "mfPr",
  "mfunc", "mfuncPr", "mgroupChr",
  "mgroupChrPr", "mgrow", "mhideBot", "mhideLeft", "mhideRight",
  "mhideTop", "mhtmltag",
  "mlim", "mlimloc", "mlimlow", "mlimlowPr", "mlimupp",
  "mlimuppPr", "mm", "mmaddfieldname",
  "mmath", "mmathPict", "mmathPr", "mmaxdist", "mmc", "mmcJc",
  "mmconnectstr", "mmconnectstrdata", "mmcPr", "mmcs",
  "mmdatasource", "mmheadersource", "mmmailsubject",
  "mmodso", "mmodsofilter", "mmodsofldmpdata", "mmodsomappedname",
  "mmodsoname", "mmodsorecipdata", "mmodsosort",
  "mmodsosrc", "mmodsotable", "mmodsoudl",
  "mmodsoudldata", "mmodsouniquetag", "mmPr",
  "mmquery", "mmr", "mnary", "mnaryPr",
  "mnoBreak", "mnum", "mobjDist", "moMath", "moMathPara",
  "moMathParaPr", "mopEmu",
  "mphant", "mphantPr", "mplcHide", "mpos", "mr", "mrad",
  "mradPr", "mrPr", "msepChr",
  "mshow", "mshp", "msPre", "msPrePr", "msSub", "msSubPr",
  "msSubSup", "msSubSupPr", "msSup",
  "msSupPr", "mstrikeBLTR", "mstrikeH", "mstrikeTLBR", "mstrikeV",
  "msub", "msubHide", "msup", "msupHide", "mtransp", "mtype",
  "mvertJc", "mvfmf", "mvfml", "mvtof", "mvtol",
  "mzeroAsc", "mzeroDesc", "mzeroWid", "nesttableprops",
  "nextfile", "nonesttables",
  "objalias", "objclass", "objdata", "object", "objname",
  "objsect", "objtime", "oldcprops",
  "oldpprops", "oldsprops", "oldtprops", "oleclsid", "operator",
  "panose", "password",
  "passwordhash", "pgp", "pgptbl", "picprop", "pict", "pn", "pnseclvl",
  "pntext", "pntxta",
  "pntxtb", "printim", "private", "propname", "protend", "protstart",
  "protusertbl", "pxe",
  "result", "revtbl", "revtim", "rsidtbl", "rxe", "shp", "shpgrp", "shpinst",
  "shppict", "shprslt", "shptxt", "sn",
  "sp", "staticval", "stylesheet", "subject", "sv",
  "svb", "tc", "template", "themedata", "title", "txe", "ud",
  "upr", "userprops",
  "wgrffmtfilter", "windowcaption", "writereservation", "writereservhash",
  "xe", "xform", "xmlattrname", "xmlattrvalue",
  "xmlclose", "xmlname", "xmlnstbl", "xmlopen"
)



.specialchars <- list(
  keys = c("bullet", "emdash", "emspace", "endash", "enspace",
           "ldblquote", "line", "lquote", "page", "par",
           "qmspace", "rdblquote", "rquote", "sect", "tab",
           # table controls.
           # - \trowd... begining or row
           # - \row  ... end of each row
           # - \cell ... end of each cell
           "trowd", "row", "cell"),
  hexstr = c("x2022", "x2014", "x2003", "x2013", "x2002",
             "x201C", "x000A", "xu2018", "x000Ax000A", "x000A",
             "x2005", "x201D", "x2019", "x000Ax000A", "x0009",
             "x007c", "x000A", "x0009"),
  str = c("\u2022", "\u2014", "\u2003", "\u2013", "\u2002",
          "\201C", "\n", "\u2018", "\n\n", "\n",
          "\u2005", "\u201D", "\u2019",  "\n\n", "\t",
          "|", "\n", "\t")
)

# c++ code requires that key is increasing
.specialchars <- lapply(.specialchars, `[`, order(.specialchars$key))
